//
//  ContactsTableViewController.swift
//  PhoneBook
//
//  Created by Santiago Pavón on 26/11/14.
//  Copyright (c) 2014 UPM. All rights reserved.
//

import UIKit

private let CONTACTBOOK_FILENAME = "agenda.plist"

class ContactsTableViewController: UITableViewController {

    var contactBook: ContactBook = ContactBook()
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Uncomment the following line to preserve selection between presentations
        // self.clearsSelectionOnViewWillAppear = false

        // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
        self.navigationItem.leftBarButtonItem = self.editButtonItem()
        
        contactBook.loadOrCreate(CONTACTBOOK_FILENAME)
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }


    
    // MARK: - Table view data source

    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return 1
    }

    
    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return contactBook.contacts.count
    }

    
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCellWithIdentifier("Contact Cell", forIndexPath: indexPath) as ContactCell

        let contact = contactBook.contacts[indexPath.row]
        
        cell.nameLabel.text = contact.name
        cell.addressLabel.text = contact.address
        cell.phoneLabel.text = contact.phone

        return cell
    }

    
    /*
    // Override to support conditional editing of the table view.
    override func tableView(tableView: UITableView, canEditRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return NO if you do not want the specified item to be editable.
        return true
    }
    */

    

    // Override to support editing the table view.
    override func tableView(tableView: UITableView,
         commitEditingStyle editingStyle: UITableViewCellEditingStyle,
          forRowAtIndexPath indexPath: NSIndexPath) {

        if editingStyle == .Delete {
            
            // Delete the row from the data source
            contactBook.contacts.removeAtIndex(indexPath.row)
            
            contactBook.save(CONTACTBOOK_FILENAME)
            
            tableView.deleteRowsAtIndexPaths([indexPath], withRowAnimation: .Fade)
            
        } else if editingStyle == .Insert {
            
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }    
    }

    
    
    /*
    // Override to support rearranging the table view.
    override func tableView(tableView: UITableView, moveRowAtIndexPath fromIndexPath: NSIndexPath, toIndexPath: NSIndexPath) {

    }
    */

    /*
    // Override to support conditional rearranging of the table view.
    override func tableView(tableView: UITableView, canMoveRowAtIndexPath indexPath: NSIndexPath) -> Bool {
        // Return NO if you do not want the item to be re-orderable.
        return true
    }
    */

    
    
    // MARK: - Navigation

    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        
        if segue.identifier == "Editing Contact" {
            
            if let ecvc = segue.destinationViewController
                       as? EditContactTableViewController {
                if let ip = tableView.indexPathForSelectedRow() {
                    ecvc.contact = contactBook.contacts[ip.row]
                }
            }
            
        } else if segue.identifier == "Adding Contact" {
            if let ecvc = segue.destinationViewController
                as? EditContactTableViewController {
                    
                    let newContact = Contact(name: "", address: "", phone: "")
                    contactBook.contacts.insert(newContact, atIndex: 0)
                    
                    let ip = NSIndexPath(forRow: 0, inSection: 0)
                    tableView.insertRowsAtIndexPaths([ip],
                                    withRowAnimation: .Automatic)
                    
                    tableView.selectRowAtIndexPath(ip, animated: true,
                                                   scrollPosition: .Top)
                    
                    ecvc.contact = newContact
            }
        }
    }
    
    @IBAction func contactWasChanged(segue: UIStoryboardSegue) {
       
        if let ip = tableView.indexPathForSelectedRow() {
           
            tableView.reloadRowsAtIndexPaths([ip],
                            withRowAnimation: .Automatic)
            
            contactBook.save(CONTACTBOOK_FILENAME)

        }
        
    }
}













